@@ -1,13 +1,12 @@
 package File::Rename;
 
-use strict;
-use warnings;
+use 5.032;  # use strict; use warnings;
 
 require Exporter;
 our @ISA = qw(Exporter);
 our @EXPORT_OK = qw( rename );
 
-our $VERSION = '2.00_4';
+our $VERSION = '2.01_91';
 
 sub import {
     my $pack = shift;
@@ -306,7 +305,7 @@ Errors from the code argument are not trapped.
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2004, 2005, 2006, 2011, 2018, 2021, 2022 
+Copyright (C) 2004, 2005, 2006, 2011, 2018, 2021, 2022, 2023
 by Robin Barker
 
 This library is free software; you can redistribute it and/or modify
